# What is ScrapydArt? click here.

### 爬虫部署方式以及说明请参照： scrapydartx 功能扩展说明

被调用过的爬虫 : {invoked_spider}

被调用次数最多 : {most_spider},{most_num}次

未被调用的爬虫 : {un_invoked_spider}

发生异常被终止的爬虫 : {unormal_spiders}

# 爬虫运行信息一览

{nop}
number of spider pending
{nor}
number of spider running
{nof}
number of spider finished
{average}
Average time of spider running
{shortest}
Shortest time of spider running
{longest}
Longest time of spider running

# 项目信息一览

{lpn}
当前项目总数
{lsn}
当前爬虫总数

项目名称 | 爬虫名称 | 爬虫数量
--- | --- | ---
{table}

运行时长rank榜 | 爬虫名称 | 运行时长
--- | --- | ---
{ranks}